@@ -1,7 +1,7 @@
 #
 #    predict.ppm.S
 #
-#	$Revision: 1.115 $	$Date: 2022/06/12 04:40:18 $
+#	$Revision: 1.117 $	$Date: 2023/05/02 07:31:44 $
 #
 #    predict.ppm()
 #	   From fitted model obtained by ppm(),	
@@ -69,9 +69,11 @@ predict.ppm <- local({
                           correction,
                           ignore.hardcore=FALSE,
                           ...,
-                          dimyx=NULL, eps=NULL, 
+                          dimyx=NULL, eps=NULL,
+                          rule.eps=c("adjust.eps","grow.frame","shrink.frame"),
                           new.coef=NULL, check=TRUE, repair=TRUE) {
     interval <- match.arg(interval)
+    rule.eps <- match.arg(rule.eps)
     ## extract undocumented arguments 
     xarg <- xtract(...)
     sumobj <- xarg$sumobj
@@ -334,7 +336,7 @@ predict.ppm <- local({
         }
         if(is.null(window))
           window <- sumobj$entries$data$window
-        masque <- as.mask(window, dimyx=ngrid, eps=eps)
+        masque <- as.mask(window, dimyx=ngrid, eps=eps, rule.eps=rule.eps)
       }
       ## Hack -----------------------------------------------
       ## gam with lo() will not allow extrapolation beyond the range of x,y
@@ -490,30 +492,43 @@ predict.ppm <- local({
       if(type == "intensity") 
         z <- PoisSaddle(z, fitin(model))
       
-      ##
       if(needSE) {
-        ## extract variance-covariance matrix of parameters
-        vc <- vcov(model, new.coef=new.coef)
-        ## compute model matrix
-        fmla <- rhs.of.formula(formula(glmfit))
+        ## compute standard error, needed for some purpose
+        if(inherits(glmfit, "gam")) {
+          ## compute SE using predict.gam
+          if(!is.null(new.coef))
+            warning("new.coef ignored in standard error calculation")
+          SE <- predict(glmfit, newdata=newdata, type="response",
+                        se.fit=TRUE)[[2]]
+        } else {
+          ## Use vcov.ppm
+          ## extract variance-covariance matrix of parameters
+          vc <- vcov(model, new.coef=new.coef)
+          ## compute model matrix
+          fmla <- rhs.of.formula(formula(glmfit))
 #        mf <- model.frame(fmla, newdata, ..., na.action=na.pass)
 #        mm <- model.matrix(fmla, mf, ..., na.action=na.pass)
-        mf <- model.frame(fmla, newdata, na.action=na.pass)
-        mm <- model.matrix(fmla, mf, na.action=na.pass)
-        if(nrow(mm) != nrow(newdata))
-          stop("Internal error: row mismatch in SE calculation")
-        ## compute relative variance = diagonal of quadratic form
-        if(ncol(mm) != ncol(vc))
-          stop("Internal error: column mismatch in SE calculation")
-        vv <- quadform(mm, vc)
-        ## standard error
-        SE <- lambda * sqrt(vv)
+          mf <- model.frame(fmla, newdata, na.action=na.pass)
+          mm <- model.matrix(fmla, mf, na.action=na.pass)
+          if(nrow(mm) != nrow(newdata))
+            stop("Internal error: row mismatch in SE calculation")
+          ## compute relative variance = diagonal of quadratic form
+          if(ncol(mm) != ncol(vc))
+            stop("Internal error: column mismatch in SE calculation")
+          vv <- quadform(mm, vc)
+          ## standard error
+          SE <- lambda * sqrt(vv)
+        }
+
+        ## Save desired quantities depending on SE
         if(se) 
           zse <- SE
+
         if(interval == "confidence") {
           z <- lambda + outer(SE, ci.q, "*")
           colnames(z) <- ci.names
-        } 
+        }
+        
       } 
       
       ## ############################################################  
@@ -803,7 +818,7 @@ equalpairs <- function(U, X, marked=FALSE) {
   
 fill.coefs <- function(coefs, required) {
   # 'coefs' should contain all the 'required' values
-  coefsname <- deparse(substitute(coefs))
+  coefsname <- short.deparse(substitute(coefs))
   nama <- names(coefs)
   if(is.null(nama)) {
     #' names cannot be matched
